@@ -3,7 +3,11 @@ from typing import List, Optional, Set, Tuple, Union
 import torch
 from transformers import PreTrainedModel, PreTrainedTokenizer, PreTrainedTokenizerFast
 
-from transformers_visualizer.errors import DimensionIndicesError, OutputNotComputedEror
+from transformers_visualizer.errors import (
+    DimensionIndicesError,
+    OutputNotComputedEror,
+    TextInputError,
+)
 from transformers_visualizer.plotting import plot_token_to_token_specific_dimension
 from transformers_visualizer.visualizer import Visualizer
 
@@ -49,15 +53,10 @@ class TokenToTokenAttentions(Visualizer):
         Args:
             text (str): Text input.
         """
-        if (
-            isinstance(text, List) or isinstance(text, Tuple) or isinstance(text, Set)  # type: ignore
-        ):
-            raise NotImplementedError("Multiple text input is not supported.")
+        if isinstance(text, Tuple) or isinstance(text, List) or isinstance(text, Set):  # type: ignore
+            raise TextInputError
 
         self.tokens = self.tokenizer(text, return_tensors="pt").to(self._device)
-        self.all_tokens: List[str] = self.tokenizer.convert_ids_to_tokens(
-            self.tokens["input_ids"].squeeze().tolist()  # type: ignore
-        )
 
         self.output = self.model(**self.tokens)
         self.attentions = torch.concat(self.output.attentions)
@@ -71,12 +70,15 @@ class TokenToTokenAttentions(Visualizer):
         """
         return super().compute(text)
 
-    def plot(self, layer_index: int = -1, **plot_kwargs) -> None:
+    def plot(
+        self, layer_index: int = -1, skip_special_tokens: bool = False, **plot_kwargs
+    ) -> None:
         """
         Plot the Visualizer. The purpose of kwargs are used to setup plotting parameters.
 
         Args:
             layer_index (int): Layer index of the model to be plotted. Defaults to last layer, i.e. -1.
+            skip_special_tokens (bool): If True, plot doesn't contains special tokens. Defaults to False.
             figsize (Tuple[int, int], optional): Figsize of the plot. Defaults to (20, 20).
             ticks_fontsize (int, optional): Ticks fontsize. Defaults to 7.
             title_fontsize (int, optional): Title fontsize. Defaults to 9.
@@ -86,7 +88,7 @@ class TokenToTokenAttentions(Visualizer):
         Raises:
             OutputNotComputedEror: raised if no `Output` present.
         """
-        if not hasattr(self, "attentions") or not hasattr(self, "all_tokens"):
+        if not hasattr(self, "attentions"):
             raise OutputNotComputedEror
 
         max_layer_index = self.model.config.num_hidden_layers - 1
@@ -95,9 +97,25 @@ class TokenToTokenAttentions(Visualizer):
         except IndexError:
             raise DimensionIndicesError("layer_index", layer_index, max_layer_index)
 
+        if skip_special_tokens:
+            special_tokens_mask = self.tokenizer.get_special_tokens_mask(
+                self.tokens.input_ids.squeeze(), already_has_special_tokens=True
+            )
+            special_tokens_mask = (
+                torch.where(torch.tensor(special_tokens_mask) == 1, 0, 1)
+                .to(torch.bool)
+                .squeeze()
+            )
+            attentions = attentions[..., special_tokens_mask]
+            attentions = attentions[:, special_tokens_mask]
+
+        all_tokens: List[str] = self.tokenizer.convert_ids_to_tokens(
+            self.tokens["input_ids"].squeeze(), skip_special_tokens=skip_special_tokens  # type: ignore
+        )
+
         plot_token_to_token_specific_dimension(
             attentions,
-            self.all_tokens,
+            all_tokens,
             "Head",
             **plot_kwargs,
         )
@@ -154,12 +172,12 @@ class TokenToTokenNormalizedAttentions(Visualizer):
             text (str): Text input.
             order (Optional[Union[str, int]]): Order used when `torch.norm` is applied.
         """
-        tokens = self.tokenizer(text, return_tensors="pt").to(self._device)
-        self.all_tokens: List[str] = self.tokenizer.convert_ids_to_tokens(
-            tokens["input_ids"].squeeze().tolist()  # type: ignore
-        )
+        if isinstance(text, Tuple) or isinstance(text, List) or isinstance(text, Set):  # type: ignore
+            raise TextInputError
 
-        self.output = self.model(**tokens)
+        self.tokens = self.tokenizer(text, return_tensors="pt").to(self._device)
+
+        self.output = self.model(**self.tokens)
         self.attentions = torch.concat(self.output.attentions)
         self.normalized_attentions = torch.linalg.norm(
             self.attentions, dim=1, ord=order
@@ -175,11 +193,12 @@ class TokenToTokenNormalizedAttentions(Visualizer):
         self.__call__(text, order)
         return self
 
-    def plot(self, **plot_kwargs) -> None:
+    def plot(self, skip_special_tokens: bool = False, **plot_kwargs) -> None:
         """
         Plot the Visualizer. The purpose of kwargs are used to setup plotting parameters.
 
         Args:
+            skip_special_tokens (bool): If True, plot doesn't contains special tokens. Defaults to False.
             figsize (Tuple[int, int], optional): Figsize of the plot. Defaults to (20, 20).
             ticks_fontsize (int, optional): Ticks fontsize. Defaults to 7.
             title_fontsize (int, optional): Title fontsize. Defaults to 9.
@@ -189,16 +208,31 @@ class TokenToTokenNormalizedAttentions(Visualizer):
         Raises:
             OutputNotComputedEror: raised if no `Output` present.
         """
-        if (
-            not hasattr(self, "attentions")
-            or not hasattr(self, "normalized_attentions")
-            or not hasattr(self, "all_tokens")
+        if not hasattr(self, "attentions") or not hasattr(
+            self, "normalized_attentions"
         ):
             raise OutputNotComputedEror
 
+        if skip_special_tokens:
+            special_tokens_mask = self.tokenizer.get_special_tokens_mask(
+                self.tokens.input_ids.squeeze(), already_has_special_tokens=True
+            )
+            special_tokens_mask = (
+                torch.where(torch.tensor(special_tokens_mask) == 1, 0, 1)
+                .to(torch.bool)
+                .squeeze()
+            )
+            normalized_attentions = self.normalized_attentions[..., special_tokens_mask]
+            normalized_attentions = normalized_attentions[:, special_tokens_mask]
+        else:
+            normalized_attentions = self.normalized_attentions
+
+        all_tokens: List[str] = self.tokenizer.convert_ids_to_tokens(
+            self.tokens["input_ids"].squeeze(), skip_special_tokens=skip_special_tokens  # type: ignore
+        )
         plot_token_to_token_specific_dimension(
-            self.normalized_attentions,
-            self.all_tokens,
+            normalized_attentions,
+            all_tokens,
             "Layer",
             **plot_kwargs,
         )
